pro mk_mlo_struct,dummy
;+
; NAME:
;	MK_MLO_STRUCT
;
; PURPOSE:
; 	This procedure generates a structure type for the HAO-MLO fits files.
;
; CATEGORY:
;	LASCO DATA ANALYSIS
;
; CALLING SEQUENCE:
;	MK_MLO_STRUCT
;
; INPUTS:
;	None
;
; OUTPUTS:
;	The procedure generates a file with the desired structure.
;
; SIDE EFFECTS:
;	Writes a file to $NRL_LIB/lasco/inout
;
; EXAMPLE:
;	To generate a sample header, you must have a new copy of IDL, or at least one
;	that hasn't had the MLO structure defined.
;
;	MK_MLO_STRUCT
;
; MODIFICATION HISTORY:
;  	05.08.19, nr - add RSUN
;
; 	Written by:	RAHoward, NRL, Oct, 1998
;
;-
; @(#)mk_mlo_struct.pro	1.4 08/19/05 :LASCO IDL LIBRARY
;

mlo_hdr_struct=CREATE_STRUCT(NAME='mlo_hdr_struct',[$
'simple','bitpix','naxis','naxis1','naxis2', $
'filename','object','type_obs','origin','telescop', $
'detector','instrume','date_obs','time_obs','ctype1',  $
'crpix1','crval1','cdelt1','crota1','ctype2',  $
'crpix2','crval2','cdelt2','crota2','crradius',   $
'bunit','bscale','bzero','datamin','datamax',  $
'dispmin','dispmax','diraxis1','diraxis2','version',   $
'rmin',     $
'rmax',    $
'filter','waveleng','polar','r1col','r2col',  $
'r1row','r2row','exptime','expcmd','exp0',     $
'mid_date','mid_time','readport','lebxsum','lebysum',   $
'sumcol','sumrow','rsun','cunit1','cunit2','comment','history'], $
1,0,0,0,0,   '','','','','',    '','','','','',    $
0.0,0.0,0.0,0.0,'',   0.0,0.0,0.0,0.0,0.0,  $
'',0.0,0,0.0,0.0,     0.0,0.0,'','','',     $
0,         0,       $
'',0.0,'',0,0,         0,0,0.0,0.0,0.0,      $
0L,0.0,'',0,0,        0,0,0.0,'','',STRARR(50) ,STRARR(50))
mlo_hdr_tags = TAG_NAMES(mlo_hdr_struct)
SAVE,mlo_hdr_struct,mlo_hdr_tags,  $
     FILENAME=FILEPATH('example_mlo_hdr.dat',ROOT_DIR='$NRL_LIB',SUBDIRECTORY=['lasco','inout'])
RETURN
END
