;+
; Project     : SOHO - LASCO
;                   
; Name        : MLO_FITSHDR2STRUCT
;               
; Purpose     : Converts a FITS header into a structure similar to the LASCO structure
;               
; Use         : IDL> mlo_hdr = MLO_FITSHDR2STRUCT(fits_hdr)
;    
; Inputs      : fits_hdr	FITS header, STRARR
;               
; Outputs     : mlo_hdr   	MLO header structure.
;               
; Calls       : FXPAR, GETTOK
;
; Category    : Data_Handling, I_O
;               
; Prev. Hist. : None.
;
; Written     : Russ Howard, NRL, Aug. 1998. (adapted from LASCO_FITSHDR2STRUCT)
;               
; Modified    : 
;
; Version     : Version 1.0, Aug. 22, 1998
;
; 
; @(#)mlo_fitshdr2struct.pro	1.5 11/05/01 :LASCO IDL LIBRARY
;
;
;-            

;_______________________________________________________________________________
;

FUNCTION MLO_FITSHDR2STRUCT, fts_hdr

COMMON MLO_HDR_COMMON, mlo_hdr_struct, mlo_hdr_tags

   len = N_ELEMENTS(fts_hdr)

   ;** if calling for the first time we need to define the header structure
   IF (DATATYPE(mlo_hdr_struct) EQ 'UND') THEN $
      ;RESTORE, '$NRL_LIB/lasco/inout/example_mlo_hdr.dat'
      RESTORE, FILEPATH('example_mlo_hdr.dat',ROOT_DIR='$NRL_LIB',SUBDIRECTORY=['lasco','inout'])

   mlo_hdr = mlo_hdr_struct
   nt = N_ELEMENTS(mlo_hdr_tags)
   FOR t=0, nt-1 DO BEGIN ;** for each tag in the mlo hdr structure
      key = mlo_hdr_tags(t)
      IF (key EQ 'DATE_OBS') THEN key = 'DATE-OBS'
      IF (key EQ 'TIME_OBS') THEN key = 'TIME-OBS'
      var = FXPAR(fts_hdr, key, COUNT=cnt)
      IF (key EQ 'DATE-OBS')  THEN BEGIN	; put date into CCSDS format if not
         IF (STRLEN(var) EQ 8)  THEN BEGIN	; MLO format
            yy = STRMID(var,6,2)
            IF (FIX(yy) GT 80)  THEN yy='19'+yy ELSE yy='20'+yy
            mm = STRMID(var,3,2)
            dd = STRMID(var,0,2)
            var = yy+'-'+mm+'-'+dd
         ENDIF
      ENDIF
      IF ( (key EQ 'COMMENT') OR (key EQ 'HISTORY') ) THEN BEGIN  ;** only these may have multiple entries
         FOR c=0, cnt-1 DO BEGIN
            val = STRTRIM(var(c), 2)
            mlo_hdr.(t)(c) = val
         ENDFOR
      ENDIF ELSE BEGIN
         IF (DATATYPE(var(0)) EQ 'STR') THEN var = STRTRIM(var(0), 2)
         mlo_hdr.(t) = var(0)
      ENDELSE
   ENDFOR
;
;  Add detector keyword to be compatible with LASCO/EIT
;
   mlo_hdr.detector = mlo_hdr.telescop
   mlo_hdr.r1row = 1
   mlo_hdr.r2row = mlo_hdr.naxis2
   mlo_hdr.r1col = 1
   mlo_hdr.r2col = mlo_hdr.naxis1
   mlo_hdr.expcmd = 186
   mlo_hdr.exptime = mlo_hdr.expcmd
   mlo_hdr.exp0 = 0
   dte = STR2UTC(mlo_hdr.date_obs+' '+mlo_hdr.time_obs)
   mlo_hdr.mid_date = dte.mjd
   mlo_hdr.mid_time = dte.time/1000.d
   mlo_hdr.readport = 'C'
   mlo_hdr.lebxsum = 1
   mlo_hdr.lebysum = 1
   mlo_hdr.sumcol = 0
   mlo_hdr.sumrow = 0

   RETURN, mlo_hdr

END
